@@ -1,5 +1,5 @@
 from math import pi, atan2
-from typing import Optional, Union, List, Tuple, Iterable
+from typing import Optional, Union, List, Tuple, Iterable, TYPE_CHECKING
 
 import matplotlib.pyplot as plt
 from matplotlib.axes import Axes
@@ -33,6 +33,10 @@ from mpl_format.utils.color_utils import cross_fade
 from mpl_format.utils.io_utils import save_plot
 
 
+if TYPE_CHECKING:
+    from mpl_format.figures.figure_formatter import FigureFormatter
+
+
 class AxesFormatter(object):
 
     def __init__(self, axes: Optional[Axes] = None,
@@ -97,6 +101,12 @@ class AxesFormatter(object):
     def title(self) -> TextFormatter:
         return self._title
 
+    @property
+    def figure(self) -> FigureFormatter:
+
+        from mpl_format.figures.figure_formatter import FigureFormatter
+        return FigureFormatter(self._axes)
+
     # endregion
 
     # region set text
